@@ -4,4 +4,5 @@ import os
 import sys
 sys.path.append(os.path.dirname(os.path.realpath(__file__)))  # enables relative local imports
 
-import semver
+import versioning
+import info
